@@ -1,5 +1,5 @@
 package Elasticsearch::Client::0_90::Direct::Cluster;
-$Elasticsearch::Client::0_90::Direct::Cluster::VERSION = '1.03';
+$Elasticsearch::Client::0_90::Direct::Cluster::VERSION = '1.04';
 use Moo;
 with 'Elasticsearch::Role::API::0_90';
 with 'Elasticsearch::Role::Client::Direct';
@@ -17,7 +17,7 @@ Elasticsearch::Client::0_90::Direct::Cluster - A client for running cluster-leve
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 DESCRIPTION
 
@@ -50,6 +50,19 @@ Query string parameters:
 See the L<cluster health docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/cluster-health.html>
 for more information.
 
+=head2 C<pending_tasks()>
+
+    $response = $e->cluster->pending_tasks();
+
+Returns a list of cluster-level tasks still pending on the master node.
+
+Query string parameters:
+    C<local>,
+    C<master_timeout>
+
+See the L<pending tasks docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/cluster-pending.html>
+for more information.
+
 =head2 C<node_info()>
 
     $response = $e->cluster->node_info(
