@@ -10,8 +10,9 @@ my $trace
 
 my $version = $ENV{ES_VERSION} || '';
 my $api = $version =~ /^0.90/ ? '0_90::Direct' : 'Direct';
-my $body = $ENV{ES_BODY} || 'GET';
-my $cxn = $ENV{ES_CXN} || do "default_cxn.pl" || die $!;
+my $body     = $ENV{ES_BODY}     || 'GET';
+my $cxn      = $ENV{ES_CXN}      || do "default_cxn.pl" || die $!;
+my $cxn_pool = $ENV{ES_CXN_POOL} || 'Static';
 
 my $es;
 if ( $ENV{ES} ) {
@@ -19,6 +20,7 @@ if ( $ENV{ES} ) {
         nodes            => $ENV{ES},
         trace_to         => $trace,
         cxn              => $cxn,
+        cxn_pool         => $cxn_pool,
         client           => $api,
         send_get_body_as => $body
     );
